yandex-parser
==========

Class for getting snippets from yandex html


```
from yandex_parser import Yandex

snippets = Yandex("<html><body>...</body></html>").get_snippets()

Testing

python -m unittest yandex_parser.tests.test_yandex

```
